pub type SqlType = (Varchar, Varchar, Varchar, Varchar, Varchar, Datetime);Expand description
The SQL type of all of the columns on this table
pub type SqlType = (Varchar, Varchar, Varchar, Varchar, Varchar, Datetime);The SQL type of all of the columns on this table